@@ -342,11 +342,12 @@ class AFM:
                 elif re.search('\@Sens. DeflSens:', line):
                     _def_sens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
                     
-                elif re.search('\Spring Constant:', line):
+                elif re.search('\Spring constant:', line):
                     try:
                         _spr_const = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
                     except:
                         _spr_const = re.findall(r'\d+',line)[0]
+
             data.close()
 
         elif nanoscope_version == 5:
@@ -373,7 +374,7 @@ class AFM:
                 elif re.search('\Samps/line', line):
                     _samps_line = [int(s) for s in line.split() if s.isdigit()]
 
-                elif re.search('\@Sens. Deflection:', line):
+                elif re.search('\@Sens. Zscan:', line):
                     _zsens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
 
                 elif re.search('\@4:Z scale: V ', line):
@@ -382,7 +383,7 @@ class AFM:
                 elif re.search('\@Sens. Deflection:', line):
                     _def_sens = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
                     
-                elif re.search('\Spring Constant:', line):
+                elif re.search('\Spring constant:', line):
                     try:
                         _spr_const = re.findall(r'\d+',line)[0] + '.' + re.findall(r'\d+',line)[1]
                     except:
